/****************************************************************************************/
/**
  Copyright (c) 2008 Freescale Semiconductor
  Freescale Confidential Proprietary
  \file     	Pit.h
  \brief    	This file contains all Pit functions and definition declarations. 
  \author   	Freescale Semiconductor
  \author     r01160
  \author   	Guadalajara Applications Laboratory RTAC Americas
  \version    0.1
  \date     	5/23/2008 
  \warning      
  
  * History:
  
*/
/****************************************************************************************/
#ifndef _PIT_H_
  #define _PIT_H_
  
  #include "Derivative.h"
  #include "System_Cfg.h"
  #include "Adc_Filter.h"
    
/*------------------------- Type definitions --------------------------------------------------------------*/    
 typedef void(*Pit_CallbackType)(void);
    
/*--------------------- Macros --------------------------*/
/** Assign Counter value to desired Pit channel. Violates MISRA 2004 rule 11.3 and 14.3 because addressing memory mapped registers */
#define PIT_LOAD_VALUE(u8Pit_Ch, u32Val)        \
{                                               \
    switch(u8Pit_Ch)                            \
    {                                           \
       case 1:  PIT_TLVAL0 = (uint32_t)u32Val;  \
           break;                               \
       case 2:  PIT_TLVAL1 = (uint32_t)u32Val;  \
           break;                               \
       case 4:  PIT_TLVAL2 = (uint32_t)u32Val;  \
           break;                               \
       case 8:  PIT_TLVAL3 = (uint32_t)u32Val;  \
           break;                               \
       case 16:  PIT_TLVAL4 = (uint32_t)u32Val; \
           break;                               \
       case 32:  PIT_TLVAL5 = (uint32_t)u32Val; \
           break;                               \
       case 64:  PIT_TLVAL6 = (uint32_t)u32Val; \
           break;                               \
       case 128:  PIT_TLVAL7 = (uint32_t)u32Val;\
           break;                               \
       default:                                 \
           break;                               \
    }                                           \
}


 /** Pit Channel 1 */
 #define PIT_CH_1         ((uint8_t)2)
 /** Pit Channel 2 */
 #define PIT_CH_2         ((uint8_t)4)
 /** Pit Channel 3 */
 #define PIT_CH_3         ((uint8_t)8)
 /** Pit Channel 4 */
 #define PIT_CH_4         ((uint8_t)16)
 /** Pit Channel 5 */
 #define PIT_CH_5         ((uint8_t)32)
 
 /*------------------PIT Interrupt Base Times ------------------------*/
 #define _PIT_INT_TIME_33US_  ((uint32_t)0x0840)
 /** Pit Vector Interrupt Offset                   */
 #define PIT_BASE_OFFSET  ((uint8_t)148)
/** This macro Initiates the generation of all configured Pwm Signals */
 #define PWM_ENABLED         (PIT_EN  = (PIT_EN  | ((uint32_t)1<< (uint32_t)PIT_CH_1)))
 /*--------------------- Functions --------------------------*/
 void vfnPit_Init(uint8_t u8PitChannel, uint32_t u32Period);
 void vfnPit_Set_Callback_Fnc(Pit_CallbackType Callback_Fnc);
 extern void vfnPit_Ch1_Isr(void);  
 extern void vfnPit_Init_Z1(void);
 



#endif